@@ -11,7 +11,7 @@ from tornado.ioloop import IOLoop
 class TestESConnection(AsyncTestCase):
 
     def setUp(self):
-        self.io_loop = self.get_new_ioloop()
+        super(TestESConnection, self).setUp()
         self.es_connection = ESConnection("localhost", "9200", self.io_loop)
 
     def tearDown(self):
@@ -167,13 +167,14 @@ class TestESConnection(AsyncTestCase):
         response = self.wait()
         response_dict = self._verify_response_and_returns_dict(response)
         self.assertEqual(response_dict["count"], 1)
-        self.assertTrue(response.request.url.endswith('_count?df=_id&test=True'))
+        self.assertTrue('df=_id' in response.request.url)
+        self.assertTrue('test=True' in response.request.url)
 
 
 class TestESConnectionWithTornadoGen(AsyncTestCase):
 
     def setUp(self):
-        self.io_loop = self.get_new_ioloop()
+        super(TestESConnectionWithTornadoGen, self).setUp()
         self.es_connection = ESConnection("localhost", "9200", self.io_loop)
 
     def tearDown(self):
@@ -304,7 +305,8 @@ class TestESConnectionWithTornadoGen(AsyncTestCase):
         parameters = {'df': '_id', 'test': True}
         response = yield self.es_connection.count(callback=self.stop, source=source, parameters=parameters)
         self.assertCount(response, 1)
-        self.assertTrue(response.request.url.endswith('_count?df=_id&test=True'))
+        self.assertTrue('df=_id' in response.request.url)
+        self.assertTrue('test=True' in response.request.url)
 
     def assertCount(self, response, count):
         response_dict = self._verify_status_code_and_return_response(response)
